predict.ccfkms: Clustering with Conjugate Convex Functions.
Description
Classify the rows of a data matrix using conjugate convex functions.Usage
## S3 method for class 'ccfkms':
predict(object, x, drop = 1, ...)
Arguments
object
an object of class ccfkms
x
a data matrix containing test or new samples
drop
cluster size threshold
...
other (unused) arguments
Value
- A list with the following elements:
- centersa matrix of cluster means.
- sizea vector of cluster sizes.
- cla factor of cluster labels (indexes).
- inv.infthe inverted information of the partition.
Details
This is a wrapper to ccfkms which uses a single iteration
for classifying the data. In the case a drop value greater than zero is specified, all
clusters with size equal or less than this value are removed from the
classifier.
See Also
ccfkms for obtaining a classifier.