rlbmat: Block Uniform Logical Matrix Deviates
Description
Generate a uniform logical matrix deviate with a possibly overlapping
block structure.Usage
rlbmat(npat = 4, rows = 20, cols = 12, over = 4, noise = 0.01, prob = 0.8, perfect = FALSE)
Arguments
rows
number of rows per pattern
cols
number of columns per pattern
over
number of additional columns per pattern that overlap
noise
the probability of observing a one in the background (non-pattern) matrix
prob
the probability of observing TRUE in a pattern
perfect
option for overlap of the first and the last pattern
Details
Implements a test case for proximus.